date_xx Sequence Generation
# S3 method for date_yw
seq(from, to, by = 1L, ...)# S3 method for date_yq
seq(from, to, by = 1L, ...)
# S3 method for date_ym
seq(from, to, by = 1L, ...)
a positive integer scalar to increment the sequence with
(either in quarters, months or isoweeks, depending on the class of
from/to)
ignored
an integer vector with the same date_xx subclass as from/to