powered by
A simple data type for storing years. A date_y object is just an integer with an additional class attribute.
date_y
date_y(y)is_date_y(x)as_date_y(x)
is_date_y(x)
as_date_y(x)
year
any R object
date_y returns an object of type date_y
is_date_y returns TRUE or FALSE depending on whether its argument is of type date_y or not.
is_date_y
TRUE
FALSE
as_date_m attempts to coerce its argument to date_y type
as_date_m
# NOT RUN { date_y(2013) as_date_y(2016) # }
Run the code above in your browser using DataLab